==> haskell-indexed-traversable-0.1.4-159-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-indexed-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 indexed-traversable
version:              0.1.4
visibility:           public
id:                   indexed-traversable-0.1.4-10ilYqh2nxEny8IgMDEXE
key:                  indexed-traversable-0.1.4-10ilYqh2nxEny8IgMDEXE
license:              BSD-2-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Edward Kmett
synopsis:             FunctorWithIndex, FoldableWithIndex, TraversableWithIndex
description:
    This package provides three useful generalizations:

    @
    class Functor f => FunctorWithIndex i f | f -> i where
    \  imap :: (i -> a -> b) -> f a -> f b
    @

    @
    class Foldable f => FoldableWithIndex i f | f -> i where
    \  ifoldMap :: Monoid m => (i -> a -> m) -> f a -> m
    @

    @
    class (FunctorWithIndex i t, FoldableWithIndex i t, Traversable t) => TraversableWithIndex i t | t -> i where
    \  itraverse :: Applicative f => (i -> a -> f b) -> t a -> f (t b)
    @

    This package contains instances for types in GHC boot libraries.
    For some additional instances see [indexed-traversable-instances](https://hackage.haskell.org/package/indexed-traversable-instances).

    The [keys](https://hackage.haskell.org/package/keys) package provides similar functionality,
    but uses (associated) @TypeFamilies@ instead of @FunctionalDependencies@.

category:             Data
abi:                  6f7b4131c14dc5abaa6215a074e28d80
exposed:              True
exposed-modules:
    Data.Foldable.WithIndex Data.Foldable1.WithIndex
    Data.Functor.WithIndex Data.Traversable.WithIndex

hidden-modules:       CoerceCompat GhcList WithIndex
import-dirs:          /usr/lib/ghc-9.4.8/site-local/indexed-traversable-0.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/indexed-traversable-0.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/indexed-traversable-0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-indexed-traversable
hs-libraries:         HSindexed-traversable-0.1.4-10ilYqh2nxEny8IgMDEXE
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    foldable1-classes-compat-0.1.2-1JnxX2fpu3b1x1xZKRzVOp
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-indexed-traversable/html/indexed-traversable.haddock

haddock-html:         /usr/share/doc/haskell-indexed-traversable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-indexed-traversable-0.1.4-160-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-indexed-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 indexed-traversable
version:              0.1.4
visibility:           public
id:                   indexed-traversable-0.1.4-LQVPMqdYEtI3MQSrB8OBIc
key:                  indexed-traversable-0.1.4-LQVPMqdYEtI3MQSrB8OBIc
license:              BSD-2-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Edward Kmett
synopsis:             FunctorWithIndex, FoldableWithIndex, TraversableWithIndex
description:
    This package provides three useful generalizations:

    @
    class Functor f => FunctorWithIndex i f | f -> i where
    \  imap :: (i -> a -> b) -> f a -> f b
    @

    @
    class Foldable f => FoldableWithIndex i f | f -> i where
    \  ifoldMap :: Monoid m => (i -> a -> m) -> f a -> m
    @

    @
    class (FunctorWithIndex i t, FoldableWithIndex i t, Traversable t) => TraversableWithIndex i t | t -> i where
    \  itraverse :: Applicative f => (i -> a -> f b) -> t a -> f (t b)
    @

    This package contains instances for types in GHC boot libraries.
    For some additional instances see [indexed-traversable-instances](https://hackage.haskell.org/package/indexed-traversable-instances).

    The [keys](https://hackage.haskell.org/package/keys) package provides similar functionality,
    but uses (associated) @TypeFamilies@ instead of @FunctionalDependencies@.

category:             Data
abi:                  a3061f19a669ebaa674c5144af089315
exposed:              True
exposed-modules:
    Data.Foldable.WithIndex Data.Foldable1.WithIndex
    Data.Functor.WithIndex Data.Traversable.WithIndex

hidden-modules:       CoerceCompat GhcList WithIndex
import-dirs:          /usr/lib/ghc-9.4.8/site-local/indexed-traversable-0.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/indexed-traversable-0.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/indexed-traversable-0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-indexed-traversable
hs-libraries:         HSindexed-traversable-0.1.4-LQVPMqdYEtI3MQSrB8OBIc
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    foldable1-classes-compat-0.1.2-LZNwWb3aGDeJmPdZrvp31w
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-indexed-traversable/html/indexed-traversable.haddock

haddock-html:         /usr/share/doc/haskell-indexed-traversable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
